@@ -34,18 +34,24 @@ class PluginSpecPrivate;
 
 class PluginView;
 
+struct EXTENSIONSYSTEM_EXPORT TermsAndConditions
+{
+    int version;
+    QString text;
+};
+
 struct EXTENSIONSYSTEM_EXPORT PluginDependency
 {
     enum Type { Required, Optional, Test };
 
     PluginDependency() : type(Required) {}
-    PluginDependency(const QString &name, const QString &version, Type type = Required)
-        : name(name)
+    PluginDependency(const QString &id, const QString &version, Type type = Required)
+        : id(id)
         , version(version)
         , type(type)
     {}
 
-    QString name;
+    QString id;
     QString version;
     Type type;
     bool operator==(const PluginDependency &other) const;
@@ -96,17 +102,23 @@ public:
 
     // information read from the plugin, valid after 'Read' state is reached
     virtual QString name() const;
+    virtual QString id() const;
     virtual QString version() const;
     virtual QString compatVersion() const;
     virtual QString vendor() const;
+    virtual QString vendorId() const;
     virtual QString copyright() const;
     virtual QString license() const;
     virtual QString description() const;
     virtual QString longDescription() const;
     virtual QString url() const;
+    virtual QString documentationUrl() const;
     virtual QString category() const;
     virtual QString revision() const;
     virtual QRegularExpression platformSpecification() const;
+    virtual std::optional<TermsAndConditions> termsAndConditions() const;
+
+    virtual QString displayName() const;
 
     virtual bool isAvailableForHostPlatform() const;
     virtual bool isRequired() const;
@@ -119,6 +131,7 @@ public:
     virtual bool isForceEnabled() const;
     virtual bool isForceDisabled() const;
     virtual bool isSoftLoadable() const;
+    virtual bool isEffectivelySoftloadable() const;
 
     virtual QVector<PluginDependency> dependencies() const;
     virtual QJsonObject metaData() const;
@@ -146,6 +159,8 @@ public:
 
     virtual void setEnabledBySettings(bool value);
 
+    virtual Utils::FilePath installLocation(bool inUserFolder) const = 0;
+
 protected:
     virtual void setEnabledByDefault(bool value);
     virtual void setEnabledIndirectly(bool value);
@@ -173,16 +188,20 @@ private:
     std::unique_ptr<Internal::PluginSpecPrivate> d;
 };
 
-EXTENSIONSYSTEM_EXPORT Utils::expected_str<PluginSpec *> readCppPluginSpec(
+using PluginFromArchiveFactory = std::function<QList<PluginSpec *>(const Utils::FilePath &path)>;
+EXTENSIONSYSTEM_EXPORT QList<PluginFromArchiveFactory> &pluginSpecsFromArchiveFactories();
+EXTENSIONSYSTEM_EXPORT QList<PluginSpec *> pluginSpecsFromArchive(const Utils::FilePath &path);
+
+EXTENSIONSYSTEM_EXPORT Utils::expected_str<std::unique_ptr<PluginSpec>> readCppPluginSpec(
     const Utils::FilePath &filePath);
-EXTENSIONSYSTEM_EXPORT Utils::expected_str<PluginSpec *> readCppPluginSpec(
+EXTENSIONSYSTEM_EXPORT Utils::expected_str<std::unique_ptr<PluginSpec>> readCppPluginSpec(
     const QStaticPlugin &plugin);
 
 class EXTENSIONSYSTEM_TEST_EXPORT CppPluginSpec : public PluginSpec
 {
-    friend EXTENSIONSYSTEM_EXPORT Utils::expected_str<PluginSpec *> readCppPluginSpec(
+    friend EXTENSIONSYSTEM_EXPORT Utils::expected_str<std::unique_ptr<PluginSpec>> readCppPluginSpec(
         const Utils::FilePath &filePath);
-    friend EXTENSIONSYSTEM_EXPORT Utils::expected_str<PluginSpec *> readCppPluginSpec(
+    friend EXTENSIONSYSTEM_EXPORT Utils::expected_str<std::unique_ptr<PluginSpec>> readCppPluginSpec(
         const QStaticPlugin &plugin);
 
 public:
@@ -200,6 +219,8 @@ public:
 
     Utils::expected_str<void> readMetaData(const QJsonObject &pluginMetaData) override;
 
+    Utils::FilePath installLocation(bool inUserFolder) const override;
+
 protected:
     CppPluginSpec();
 
